@@ -1,9 +1,18 @@
+from __future__ import absolute_import, unicode_literals
+
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 
 class RawContent(models.Model):
+    """
+    Content type which can be used to input raw HTML code into the CMS.
+
+    The content isn't escaped and can be used to insert CSS or JS
+    snippets too.
+    """
+
     text = models.TextField(_('content'), blank=True)
 
     class Meta:
@@ -13,4 +22,3 @@ class RawContent(models.Model):
 
     def render(self, **kwargs):
         return mark_safe(self.text)
-
